@@ -23,8 +23,9 @@
 #ifndef __PANGOFT2_PRIVATE_H__
 #define __PANGOFT2_PRIVATE_H__
 
-#include "pangoft2.h"
-#include "pango-renderer.h"
+#include <pango/pangoft2.h>
+#include <pango/pangofc-fontmap.h>
+#include <pango/pango-renderer.h>
 #include <fontconfig/fontconfig.h>
 
 /* Debugging... */
@@ -76,12 +77,14 @@ struct _PangoFT2GlyphInfo
 #define PANGO_FT2_FONT(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), PANGO_TYPE_FT2_FONT, PangoFT2Font))
 #define PANGO_FT2_IS_FONT(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), PANGO_TYPE_FT2_FONT))
 
-GType pango_ft2_font_get_type (void);
+GType pango_ft2_font_get_type (void) G_GNUC_CONST;
 
 PangoFT2Font * _pango_ft2_font_new                (PangoFT2FontMap   *ft2fontmap,
 						   FcPattern         *pattern);
 FT_Library     _pango_ft2_font_map_get_library    (PangoFontMap      *fontmap);
 const char    *_pango_ft2_ft_strerror             (FT_Error           error);
+void _pango_ft2_font_map_default_substitute (PangoFcFontMap *fcfontmap,
+					     FcPattern      *pattern);
 
 void *_pango_ft2_font_get_cache_glyph_data    (PangoFont      *font,
 					       int             glyph_index);
@@ -108,8 +111,16 @@ void _pango_ft2_draw_error_underline (FT_Bitmap         *bitmap,
 #define PANGO_FT2_RENDERER(object)         (G_TYPE_CHECK_INSTANCE_CAST ((object), PANGO_TYPE_FT2_RENDERER, PangoFT2Renderer))
 #define PANGO_IS_FT2_RENDERER(object)      (G_TYPE_CHECK_INSTANCE_TYPE ((object), PANGO_TYPE_FT2_RENDERER))
 
-GType pango_ft2_renderer_get_type    (void);
+GType pango_ft2_renderer_get_type    (void) G_GNUC_CONST;
 
 PangoRenderer *_pango_ft2_font_map_get_renderer (PangoFT2FontMap *ft2fontmap);
 
+typedef struct _PangoFT2WarningHistory PangoFT2WarningHistory;
+
+struct _PangoFT2WarningHistory {
+  guint get_face		: 1;
+};
+
+extern PangoFT2WarningHistory _pango_ft2_warning_history;
+
 #endif /* __PANGOFT2_PRIVATE_H__ */
